Package: HiCParser
Type: Package
Title: Parser for HiC data in R
Date: 2025-07-22
Version: 1.4.0
URL: https://github.com/emaigne/HiCParser
BugReports: https://github.com/emaigne/HiCParser/issues
Authors@R: c(
    person("Zytnicki", "Matthias", email = "matthias.zytnicki@inrae.fr", 
      role = c("aut")),
    person("Maigné", "Élise", email = "elise.maigne@inrae.fr", 
      role = c("aut", "cre")))
Description: This package is a parser to import HiC data into R. It
        accepts several type of data: tabular files, Cooler `.cool` or
        `.mcool` files, Juicer `.hic` files or HiC-Pro `.matrix` and
        `.bed` files. The HiC data can be several files, for several
        replicates and conditions. The data is formated in an
        InteractionSet object.
License: LGPL
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
biocViews: Software, HiC, DataImport
Imports: data.table, InteractionSet, GenomicRanges,
        SummarizedExperiment, Rcpp (>= 1.0.12), S4Vectors, gtools,
        pbapply, BiocGenerics, Seqinfo
LinkingTo: Rcpp
Suggests: rhdf5, BiocStyle, knitr, sessioninfo, testthat (>= 3.0.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
Config/pak/sysreqs: zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 13:04:28 UTC
RemoteUrl: https://github.com/bioc/HiCParser
RemoteRef: RELEASE_3_23
RemoteSha: 688ecf5636fa7a362eb849b3de5805633ffebbd4
NeedsCompilation: yes
Packaged: 2026-04-29 22:17:47 UTC; root
Author: Zytnicki Matthias [aut],
  Maigné Élise [aut, cre]
Maintainer: Maigné Élise <elise.maigne@inrae.fr>
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-29 22:42:57 UTC; unix
